..
    Copyright (C) 2020 CERN.

    invenio-app-ils is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============
See installation procedure in the official documentation at
https://invenioils.docs.cern.ch

